@@ -1,20 +1,20 @@
-/***************************************************************************
-                             transactioneditor.cpp
-                             ----------
-    begin                : Wed Jun 07 2006
-    copyright            : (C) 2006 by Thomas Baumgart
-    email                : Thomas Baumgart <ipwizard@users.sourceforge.net>
-                           (C) 2017 by Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+ * Copyright 2007-2018  Thomas Baumgart <tbaumgart@kde.org>
+ * Copyright 2017-2018  Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "transactioneditor.h"
 #include "transactioneditor_p.h"
@@ -60,7 +60,7 @@
 #include "kmymoneycompletion.h"
 #include "transaction.h"
 #include "transactionform.h"
-#include "kmymoneyglobalsettings.h"
+#include "kmymoneysettings.h"
 #include "transactioneditorcontainer.h"
 
 #include "kcurrencycalculator.h"
@@ -114,7 +114,7 @@ TransactionEditor::~TransactionEditor()
   // After all, the editor is about to die
 
   //disconnect first tagCombo:
-  KTagContainer *w = dynamic_cast<KTagContainer*>(haveWidget("tag"));
+  auto w = dynamic_cast<KTagContainer*>(haveWidget("tag"));
   if (w && w->tagCombo()) {
     w->tagCombo()->disconnect(this);
   }
@@ -153,7 +153,8 @@ void TransactionEditor::setupPrecision()
   for (it_w = widgets.constBegin(); it_w != widgets.constEnd(); ++it_w) {
     QWidget * w;
     if ((w = haveWidget(*it_w)) != 0) {
-      dynamic_cast<KMyMoneyEdit*>(w)->setPrecision(prec);
+      if (auto precisionWidget = dynamic_cast<KMyMoneyEdit*>(w))
+        precisionWidget->setPrecision(prec);
     }
   }
 }
@@ -268,12 +269,13 @@ bool TransactionEditor::eventFilter(QObject* o, QEvent* e)
 
   // if the object is a widget, the event is a key press event and
   // the object is one of our edit widgets, then ....
+  auto numberWiget = dynamic_cast<QWidget*>(o);
   if (o->isWidgetType()
       && (e->type() == QEvent::KeyPress)
-      && d->m_editWidgets.values().contains(dynamic_cast<QWidget*>(o))) {
-    QKeyEvent* k = dynamic_cast<QKeyEvent*>(e);
-    if ((k->modifiers() & Qt::KeyboardModifierMask) == 0
-        || (k->modifiers() & Qt::KeypadModifier) != 0) {
+      && numberWiget && d->m_editWidgets.values().contains(numberWiget)) {
+    auto k = dynamic_cast<QKeyEvent*>(e);
+    if ((k && (k->modifiers() & Qt::KeyboardModifierMask)) == 0
+        || (k && (k->modifiers() & Qt::KeypadModifier)) != 0) {
       bool isFinal = false;
       QList<const QWidget*>::const_iterator it_w;
       switch (k->key()) {
@@ -285,11 +287,11 @@ bool TransactionEditor::eventFilter(QObject* o, QEvent* e)
           // key into a TAB key to move between the fields. Of course, we only need
           // to do this as long as the appropriate option is set. In all other cases,
           // we treat the return/enter key as such.
-          if (KMyMoneyGlobalSettings::enterMovesBetweenFields()) {
+          if (KMyMoneySettings::enterMovesBetweenFields()) {
             for (it_w = d->m_finalEditWidgets.constBegin(); !isFinal && it_w != d->m_finalEditWidgets.constEnd(); ++it_w) {
               if (*it_w == o) {
-                if (dynamic_cast<const KMyMoneyEdit*>(*it_w)) {
-                  isFinal = !(dynamic_cast<const KMyMoneyEdit*>(*it_w)->value().isZero());
+                if (auto widget = dynamic_cast<const KMyMoneyEdit*>(*it_w)) {
+                  isFinal = !(widget->value().isZero());
                 } else
                   isFinal = true;
               }
@@ -306,7 +308,8 @@ bool TransactionEditor::eventFilter(QObject* o, QEvent* e)
             QApplication::sendEvent(o, &evt);
             // in case of a category item and the split button is visible
             // send a second event so that we get passed the button.
-            if (dynamic_cast<KMyMoneyCategory*>(o) && dynamic_cast<KMyMoneyCategory*>(o)->splitButton())
+            auto widget = dynamic_cast<KMyMoneyCategory*>(o);
+            if (widget && widget->splitButton())
               QApplication::sendEvent(o, &evt);
 
           } else {
@@ -329,7 +332,6 @@ void TransactionEditor::slotNumberChanged(const QString& txt)
 {
   Q_D(TransactionEditor);
   auto next = txt;
-  KMyMoneyLineEdit* number = dynamic_cast<KMyMoneyLineEdit*>(haveWidget("number"));
   QString schedInfo;
   if (!d->m_scheduleInfo.isEmpty()) {
     schedInfo = i18n("<center>Processing schedule for %1.</center>", d->m_scheduleInfo);
@@ -340,7 +342,7 @@ void TransactionEditor::slotNumberChanged(const QString& txt)
                                    "<center>Do you want to replace it with the next available number?</center>", next, d->m_account.name()) + QString("</qt>"), i18n("Duplicate number")) == KMessageBox::Yes) {
       assignNextNumber();
       next = KMyMoneyUtils::nextCheckNumber(d->m_account);
-    } else {
+    } else if (auto number = dynamic_cast<KMyMoneyLineEdit*>(haveWidget("number"))) {
       number->setText(QString());
       break;
     }
@@ -425,7 +427,7 @@ bool TransactionEditor::fixTransactionCommodity(const MyMoneyAccount& account)
             (*it_t).transaction().modifySplit(splitB);
 
           } catch (const MyMoneyException &e) {
-            qDebug("Unable to update commodity to second splits currency in %s: '%s'", qPrintable((*it_t).transaction().id()), qPrintable(e.what()));
+            qDebug("Unable to update commodity to second splits currency in %s: '%s'", qPrintable((*it_t).transaction().id()), e.what());
           }
           break;
 
@@ -461,7 +463,7 @@ bool TransactionEditor::fixTransactionCommodity(const MyMoneyAccount& account)
             (*it_t).transaction().modifySplit(splitB);
 
           } catch (const MyMoneyException &e) {
-            qDebug("Unable to update commodity to second splits currency in %s: '%s'", qPrintable((*it_t).transaction().id()), qPrintable(e.what()));
+            qDebug("Unable to update commodity to second splits currency in %s: '%s'", qPrintable((*it_t).transaction().id()), e.what());
           }
           break;
 
@@ -505,7 +507,7 @@ bool TransactionEditor::fixTransactionCommodity(const MyMoneyAccount& account)
               }
             }
           } catch (const MyMoneyException &e) {
-            qDebug("Unable to update commodity of split currency in %s: '%s'", qPrintable((*it_t).transaction().id()), qPrintable(e.what()));
+            qDebug("Unable to update commodity of split currency in %s: '%s'", qPrintable((*it_t).transaction().id()), e.what());
           }
           break;
       }
@@ -526,7 +528,7 @@ void TransactionEditor::assignNextNumber()
 {
   Q_D(TransactionEditor);
   if (canAssignNumber()) {
-    KMyMoneyLineEdit* number = dynamic_cast<KMyMoneyLineEdit*>(haveWidget("number"));
+    auto number = dynamic_cast<KMyMoneyLineEdit*>(haveWidget("number"));
     QString num = KMyMoneyUtils::nextCheckNumber(d->m_account);
     bool showMessage = true;
     int rc = KMessageBox::No;
@@ -544,20 +546,23 @@ void TransactionEditor::assignNextNumber()
         num = KMyMoneyUtils::nextCheckNumber(d->m_account);
         KMyMoneyUtils::updateLastNumberUsed(d->m_account, num);
         d->m_account.setValue("lastNumberUsed", num);
-        number->loadText(num);
+        if (number)
+          number->loadText(num);
       } else {
         num = QString();
         break;
       }
     }
-    number->setText(num);
+    if (number)
+      number->setText(num);
   }
 }
 
 bool TransactionEditor::canAssignNumber() const
 {
-  auto number = dynamic_cast<KMyMoneyLineEdit*>(haveWidget("number"));
-  return (number != 0);
+  if (dynamic_cast<KMyMoneyLineEdit*>(haveWidget("number")))
+    return true;
+  return false;
 }
 
 void TransactionEditor::setupCategoryWidget(KMyMoneyCategory* category, const QList<MyMoneySplit>& splits, QString& categoryId, const char* splitEditSlot, bool /* allowObjectCreation */)
@@ -807,8 +812,7 @@ bool TransactionEditor::enterTransactions(QString& newId, bool askForSchedule, b
         }
       }
     } catch (const MyMoneyException &e) {
-      qDebug("Unable to store transaction within engine: %s", qPrintable(e.what()));
-      newTransactionCreated = false;
+      qDebug("Unable to store transaction within engine: %s", e.what());
     }
 
     emit statusProgress(-1, -1);
@@ -822,10 +826,9 @@ void TransactionEditor::resizeForm()
 {
   Q_D(TransactionEditor);
   // force resizeing of the columns in the form
-  auto form = dynamic_cast<KMyMoneyTransactionForm::TransactionForm*>(d->m_regForm);
-  if (form) {
+
+  if (auto form = dynamic_cast<KMyMoneyTransactionForm::TransactionForm*>(d->m_regForm))
     QMetaObject::invokeMethod(form, "resize", Qt::QueuedConnection, QGenericReturnArgument(), Q_ARG(int, (int)eWidgets::eTransactionForm::Column::Value1));
-  }
 }
 
 void TransactionEditor::slotNewPayee(const QString& newnameBase, QString& id)
