@@ -1,25 +1,20 @@
-/***************************************************************************
-                          mymoneysecurity.h  -  description
-                             -------------------
-    begin                : Tue Jan 29 2002
-    copyright            : (C) 2000-2002 by Michael Edwardes
-    email                : mte@users.sourceforge.net
-                           Javier Campos Morales <javi_c@users.sourceforge.net>
-                           Felix Rodriguez <frodriguez@users.sourceforge.net>
-                           John C <thetacoturtle@users.sourceforge.net>
-                           Thomas Baumgart <ipwizard@users.sourceforge.net>
-                           Kevin Tambascio <ktambascio@users.sourceforge.net>
-                           (C) 2017 by Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+ * Copyright 2005-2017  Thomas Baumgart <tbaumgart@kde.org>
+ * Copyright 2017-2018  Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #ifndef MYMONEYSECURITY_H
 #define MYMONEYSECURITY_H
@@ -64,6 +59,8 @@ class KMM_MYMONEY_EXPORT MyMoneySecurity : public MyMoneyObject, public MyMoneyK
 
 public:
   MyMoneySecurity();
+  explicit MyMoneySecurity(const QString &id);
+
   explicit MyMoneySecurity(const QString& id,
                            const QString& name,
                            const QString& symbol = QString(),
@@ -71,8 +68,6 @@ public:
                            const int smallestAccountFraction = 100,
                            const int pricePrecision = 4);
 
-  explicit MyMoneySecurity(const QDomElement& node);
-
   MyMoneySecurity(const QString& id,
                   const MyMoneySecurity& other);
 
@@ -127,8 +122,6 @@ public:
   int pricePrecision() const;
   void setPricePrecision(const int pp);
 
-  void writeXML(QDomDocument& document, QDomElement& parent) const override;
-
   /**
    * This method checks if a reference to the given object exists. It returns,
    * a @p true if the object is referencing the one requested by the
