@@ -1,25 +1,22 @@
-/***************************************************************************
- *   Copyright 2004  Martin Preuss aquamaniac@users.sourceforge.net        *
- *   Copyright 2009  Cristian Onet onet.cristian@gmail.com                 *
- *   Copyright 2010  Thomas Baumgart ipwizard@users.sourceforge.net        *
- *   Copyright 2015  Christian David christian-david@web.de                *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
- ***************************************************************************/
+/*
+ * Copyright 2004       Martin Preuss aquamaniac@users.sourceforge.net
+ * Copyright 2009       Cristian Onet onet.cristian@gmail.com
+ * Copyright 2010-2018  Thomas Baumgart tbaumgart@kde.org
+ * Copyright 2015       Christian David christian-david@web.de
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 #include <config-kmymoney.h>
 
 #include "kbanking.h"
@@ -82,6 +79,7 @@
 #include "kmymoneyview.h"
 #include "kbpickstartdate.h"
 #include "mymoneyinstitution.h"
+#include "mymoneyexception.h"
 
 #include "gwenkdegui.h"
 #include "gwenhywfarqtoperators.h"
@@ -89,7 +87,6 @@
 #include "mymoneystatement.h"
 #include "statementinterface.h"
 #include "viewinterface.h"
-#include "kmymoneyglobalsettings.h"
 
 #ifdef KMM_DEBUG
 // Added an option to open the chipTanDialog from the menu for debugging purposes
@@ -122,7 +119,7 @@ public:
           if (exp.exactMatch(proxy)) {
             proxy = exp.cap(2);
             qDebug("Setting GWEN_PROXY to '%s'", qPrintable(proxy));
-            if (setenv("GWEN_PROXY", qPrintable(proxy), 1) == -1) {
+            if (!qputenv("GWEN_PROXY", qPrintable(proxy))) {
               qDebug("Unable to setup GWEN_PROXY");
             }
           }
@@ -174,11 +171,6 @@ KBanking::~KBanking()
   qDebug("Plugins: kbanking unloaded");
 }
 
-void KBanking::injectExternalSettings(KMyMoneySettings* p)
-{
-  KMyMoneyGlobalSettings::injectExternalSettings(p);
-}
-
 void KBanking::plug()
 {
   m_kbanking = new KBankingExt(this, "KMyMoney");
@@ -425,7 +417,7 @@ void KBanking::setupAccountReference(const MyMoneyAccount& acc, AB_ACCOUNT* ab_a
 
     QString val = QString("%1-%2").arg(routingNumber, accountNumber);
     if (val != acc.onlineBankingSettings().value("kbanking-acc-ref")) {
-      MyMoneyKeyValueContainer kvp;
+      kvp.clear();
 
       // make sure to keep our own previous settings
       const QMap<QString, QString>& vals = acc.onlineBankingSettings().pairs();
@@ -670,7 +662,7 @@ QStringList KBanking::availableJobs(QString accountId)
       d->jobList.clear();
       d->fileId = id;
     }
-  } catch (const MyMoneyException&) {
+  } catch (const MyMoneyException &) {
     // Exception usually means account was not found
     return QStringList();
   }
@@ -818,14 +810,20 @@ void KBanking::slotClearPasswordCache()
 
 void KBanking::slotImport()
 {
+  m_statementCount = 0;
+  statementInterface()->resetMessages();
+
   if (!m_kbanking->interactiveImport())
     qWarning("Error on import dialog");
+  else
+    statementInterface()->showMessages(m_statementCount);
 }
 
 
 bool KBanking::importStatement(const MyMoneyStatement& s)
 {
-  return statementInterface()->import(s);
+  m_statementCount++;
+  return !statementInterface()->import(s).isEmpty();
 }
 
 
@@ -926,9 +924,9 @@ int KBankingExt::executeQueue(AB_IMEXPORTER_CONTEXT *ctx)
         job.setJobSend();
 
       if (abStatus == AB_Job_StatusFinished)
-        job.setBankAnswer(onlineJob::acceptedByBank);
+        job.setBankAnswer(eMyMoney::OnlineJob::sendingState::acceptedByBank);
       else if (abStatus == AB_Job_StatusError || abStatus == AB_Job_StatusUnknown)
-        job.setBankAnswer(onlineJob::sendingError);
+        job.setBankAnswer(eMyMoney::OnlineJob::sendingState::sendingError);
 
       job.addJobMessage(onlineJobMessage(eMyMoney::OnlineJob::MessageType::Debug, "KBanking", "Job was processed"));
       m_parent->m_onlineJobQueue.insert(jobIdent, job);
@@ -1279,7 +1277,14 @@ void KBankingExt::_xaToStatement(MyMoneyStatement &ks,
       memo.append(QString("DEBT: %1").arg(p));
     }
   }
-  kt.m_strMemo = memo;
+
+  const MyMoneyKeyValueContainer& kvp = acc.onlineBankingSettings();
+  // check if we need the version with or without linebreaks
+  if (kvp.value("kbanking-memo-removelinebreaks").compare(QLatin1String("no"))) {
+    kt.m_strMemo = memo;
+  } else {
+    kt.m_strMemo = s;
+  }
 
   // calculate the hash code and start with the payee info
   // and append the memo field
@@ -1287,7 +1292,6 @@ void KBankingExt::_xaToStatement(MyMoneyStatement &ks,
   h = MyMoneyTransaction::hash(s, h);
 
   // see, if we need to extract the payee from the memo field
-  const MyMoneyKeyValueContainer& kvp = acc.onlineBankingSettings();
   QString rePayee = kvp.value("kbanking-payee-regexp");
   if (!rePayee.isEmpty() && kt.m_strPayee.isEmpty()) {
     QString reMemo = kvp.value("kbanking-memo-regexp");
@@ -1324,10 +1328,10 @@ void KBankingExt::_xaToStatement(MyMoneyStatement &ks,
 
     if (!startTime)
       startTime = ti;
-    else {
+    /*else { dead code
       if (GWEN_Time_Diff(ti, startTime) < 0)
         startTime = ti;
-    }
+    }*/
 
     if (!GWEN_Time_GetBrokenDownDate(ti, &day, &month, &year)) {
       kt.m_datePosted = QDate(year, month + 1, day);
@@ -1462,8 +1466,6 @@ bool KBankingExt::importAccountInfo(AB_IMEXPORTER_ACCOUNTINFO *ai,
       ks.m_eType = eMyMoney::Statement::Type::Investment;
       break;
     case AB_AccountType_Cash:
-      ks.m_eType = eMyMoney::Statement::Type::None;
-      break;
     default:
       ks.m_eType = eMyMoney::Statement::Type::None;
   }
