@@ -1,19 +1,20 @@
-/***************************************************************************
-                          transaction.cpp  -  description
-                             -------------------
-    begin                : Tue Jun 13 2006
-    copyright            : (C) 2000-2006 by Thomas Baumgart <ipwizard@users.sourceforge.net>
-                           (C) 2017 by Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+ * Copyright 2006-2018  Thomas Baumgart <tbaumgart@kde.org>
+ * Copyright 2017-2018  Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "transaction.h"
 #include "transaction_p.h"
@@ -55,7 +56,7 @@
 #include "registerfilter.h"
 #include "tabbar.h"
 
-#include "kmymoneyglobalsettings.h"
+#include "kmymoneysettings.h"
 #include "widgetenums.h"
 #include "mymoneyenums.h"
 
@@ -157,8 +158,7 @@ Transaction::Transaction(Register *parent, const MyMoneyTransaction& transaction
 }
 
 Transaction::Transaction(TransactionPrivate &dd, Register* parent, const MyMoneyTransaction& transaction, const MyMoneySplit& split, int uniqueId) :
-  RegisterItem(dd, parent),
-  d_ptr(&dd)
+  RegisterItem(dd, parent)
 {
   Q_D(Transaction);
   d->m_form = nullptr;
@@ -224,14 +224,14 @@ void Transaction::setFocus(bool focus, bool updateLens)
     d->m_focus = focus;
   }
   if (updateLens) {
-    if (KMyMoneyGlobalSettings::ledgerLens()
-        || !KMyMoneyGlobalSettings::transactionForm()
-        || KMyMoneyGlobalSettings::showRegisterDetailed()
+    if (KMyMoneySettings::ledgerLens()
+        || !KMyMoneySettings::transactionForm()
+        || KMyMoneySettings::showRegisterDetailed()
         || d->m_parent->ledgerLens()) {
       if (focus)
         setNumRowsRegister(numRowsRegister(true));
       else
-        setNumRowsRegister(numRowsRegister(KMyMoneyGlobalSettings::showRegisterDetailed()));
+        setNumRowsRegister(numRowsRegister(KMyMoneySettings::showRegisterDetailed()));
     }
   }
 }
@@ -374,7 +374,7 @@ bool Transaction::paintRegisterCellSetup(QPainter *painter, QStyleOptionViewItem
 
   // do we need to switch to the error color?
   if (d->m_erroneous) {
-    option.palette.setColor(QPalette::Text, KMyMoneyGlobalSettings::schemeColor(SchemeColor::TransactionErroneous));
+    option.palette.setColor(QPalette::Text, KMyMoneySettings::schemeColor(SchemeColor::TransactionErroneous));
   }
 
   // do we need to switch to the negative balance color?
@@ -383,7 +383,7 @@ bool Transaction::paintRegisterCellSetup(QPainter *painter, QStyleOptionViewItem
     if (d->m_account.accountGroup() == eMyMoney::Account::Type::Liability && !d->m_balance.isZero())
       showNegative = !showNegative;
     if (showNegative)
-      option.palette.setColor(QPalette::Text, KMyMoneyGlobalSettings::schemeColor(SchemeColor::TransactionErroneous));
+      option.palette.setColor(QPalette::Text, KMyMoneySettings::schemeColor(SchemeColor::TransactionErroneous));
   }
   return true;
 }
@@ -646,7 +646,7 @@ bool Transaction::haveNumberField() const
     case eMyMoney::Account::Type::Asset:
     case eMyMoney::Account::Type::Liability:
     case eMyMoney::Account::Type::Equity:
-      rc = KMyMoneyGlobalSettings::alwaysShowNrField();
+      rc = KMyMoneySettings::alwaysShowNrField();
       break;
 
     case eMyMoney::Account::Type::Checkings:
@@ -731,8 +731,8 @@ void Transaction::startEditMode()
   d->m_inEdit = true;
 
   // hide the original tabbar since the edit tabbar will be added
-  KMyMoneyTransactionForm::TransactionForm* form = dynamic_cast<KMyMoneyTransactionForm::TransactionForm*>(d->m_form);
-  form->getTabBar()->setVisible(false);
+  if (auto form = dynamic_cast<KMyMoneyTransactionForm::TransactionForm*>(d->m_form))
+    form->getTabBar()->setVisible(false);
 
   // only update the number of lines displayed if we edit inside the register
   if (d->m_inRegisterEdit)
@@ -748,8 +748,8 @@ void Transaction::leaveEditMode()
 {
   Q_D(Transaction);
   // show the original tabbar since the edit tabbar was removed
-  KMyMoneyTransactionForm::TransactionForm* form = dynamic_cast<KMyMoneyTransactionForm::TransactionForm*>(d->m_form);
-  form->getTabBar()->setVisible(true);
+  if (auto form = dynamic_cast<KMyMoneyTransactionForm::TransactionForm*>(d->m_form))
+    form->getTabBar()->setVisible(true);
 
   // make sure we reset the row height of all the transaction's rows because it could have been changed during edit
   if (d->m_parent) {
@@ -863,8 +863,8 @@ bool Transaction::matches(const RegisterFilter& filter) const
       QString r = split.value().formatMoney(d->m_account.fraction(), false);
       if (r.contains(s, Qt::CaseInsensitive))
         return true;
-      const MyMoneyAccount& acc = file->account(split.accountId());
-      r = split.shares().formatMoney(acc.fraction(), false);
+      const MyMoneyAccount& splitAcc = file->account(split.accountId());
+      r = split.shares().formatMoney(splitAcc.fraction(), false);
       if (r.contains(s, Qt::CaseInsensitive))
         return true;
     }
@@ -907,8 +907,7 @@ void Transaction::setVisible(bool visible)
       // about it so that they don't show the balance
       p = prevItem();
       while (p) {
-        t = dynamic_cast<Transaction*>(p);
-        if (t) {
+        if ((t = dynamic_cast<Transaction*>(p))) {
           if (!t->d_func()->m_showBalance)
             break;
           t->d_func()->m_showBalance = false;
@@ -929,8 +928,7 @@ void Transaction::setVisible(bool visible)
         d->m_showBalance = true;
         p = prevItem();
         while (p && p->isVisible()) {
-          t = dynamic_cast<Transaction*>(p);
-          if (t) {
+          if ((t = dynamic_cast<Transaction*>(p))) {
             if (t->d_func()->m_showBalance)
               break;
             t->d_func()->m_showBalance = true;
